
TODO: TODO_66_09_41_16: clarify command line processing

Command line processing evolved organically and has a trail of obsolete concepts, old meanings, outdated logic
which has to be iteratively reviewed, clarified and cleaned up.

This task is an umbrella for that to have grouping id for multiple places requiring attention.
